Package API
===========

.. module:: idom


Component
---------

.. automodule:: idom.core.component
    :members:


Hooks
-----

.. automodule:: idom.core.hooks
    :members:


Layout
------

.. automodule:: idom.core.layout
    :members:


Dispatcher
----------

.. automodule:: idom.core.dispatcher
    :members:


Server Base
-----------

.. automodule:: idom.server.base
    :members:


Sanic Servers
-------------

.. automodule:: idom.server.sanic
    :members:


Flask Servers
-------------

.. automodule:: idom.server.flask
    :members:


Tornado Servers
---------------

.. automodule:: idom.server.tornado
    :members:


HTML Widgets
------------

.. automodule:: idom.widgets.html
    :members:
    :undoc-members:


Widget Tools
------------

.. automodule:: idom.widgets.utils
    :members:


Dialect
-------

.. automodule:: idom.dialect
    :members:


Client
------

.. automodule:: idom.client.module
    :members:

.. automodule:: idom.client.manage
    :members:

.. automodule:: idom.client.utils
    :members:


Useful Tools
------------

.. automodule:: idom.utils
    :members:
